@@ -50,23 +50,23 @@
 /////////////////////// Local includes
 
 // For the install directory defines
-#include "config.h"
+#include <config.h>
 
-#include "MainWindow.hpp"
+#include <massxpert/gui/MainWindow.hpp>
 
-#include "PolChemDefSpec.hpp"
-#include "PolChemDefCatParser.hpp"
+#include <massxpert/nongui/PolChemDefSpec.hpp>
+#include <massxpert/nongui/PolChemDefCatParser.hpp>
 
-#include "ConfigSettingsDlg.hpp"
+#include <massxpert/gui/ConfigSettingsDlg.hpp>
 
-#include "PolChemDefWnd.hpp"
-#include "CalculatorWnd.hpp"
-#include "SequenceEditorWnd.hpp"
-#include "MzLabWnd.hpp"
-#include "AboutMassXpertDlg.hpp"
-#include "MassListSorterDlg.hpp"
-#include "SeqToolsDlg.hpp"
-#include "ConfigSetting.hpp"
+#include <massxpert/gui/PolChemDefWnd.hpp>
+#include <massxpert/gui/CalculatorWnd.hpp>
+#include <massxpert/gui/SequenceEditorWnd.hpp>
+#include <massxpert/gui/MzLabWnd.hpp>
+#include <massxpert/gui/AboutMassXpertDlg.hpp>
+#include <massxpert/gui/MassListSorterDlg.hpp>
+#include <massxpert/gui/SeqToolsDlg.hpp>
+#include <massxpert/nongui/ConfigSetting.hpp>
 
 
 namespace msXpSmassXpert
