@@ -41,8 +41,10 @@
 
 
 ////////////////////////////// local includes
-#include "MassSpecDataFileLoaderBrukerXy.hpp"
-#include "globals.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderBrukerXy.hpp>
+#include <libmass/DataPoint.hpp>
+
+#include <minexpert/nongui/globals.hpp>
 
 
 namespace msXpSmineXpert
@@ -292,7 +294,7 @@ namespace msXpSmineXpert
 					//qDebug() << __FILE__ << __LINE__
 						//<< "Appending MassPeak:" << mz << "-" << i;
 
-					massSpectrum->append(new msXpSlibmass::MassPeak(mz, i));
+					massSpectrum->append(new msXpSlibmass::DataPoint(mz, i));
 				}
 			}
 
@@ -417,7 +419,7 @@ namespace msXpSmineXpert
 					// We are reading in streamed mode. This is the chance we
 					// have to compute the TIC for the spectrum:
 
-					double newTic = newSpectrum->tic();
+					double newTic = newSpectrum->valSum();
 
 					// Had already another spectrum have the same rt ? If so
 					// another TIC was already computed.
@@ -814,8 +816,8 @@ namespace msXpSmineXpert
 			// End of
 			// while(!file.atEnd())
 
-			*keyVector = QVector<double>::fromList(combinedMassSpectrum.mzList());
-			*valVector = QVector<double>::fromList(combinedMassSpectrum.iList());
+			*keyVector = QVector<double>::fromList(combinedMassSpectrum.keyList());
+			*valVector = QVector<double>::fromList(combinedMassSpectrum.valList());
 
 			file.close();
 
